@@ -109,6 +109,36 @@ public abstract class Page implements Serializable {
 	private boolean xml_f = false;
 	private String	doctype_def = null;
 
+	/**
+	 * 実行状態であるか？常に true を返します。
+	 * @return true:実行中、false:モックアップ解析中。
+	 */
+	protected boolean isRuntime() {
+		return true;
+	}
+
+	/**
+	 * Paraseleneバージョンの記録。
+	 * コメントとして、Paraseleneのバージョンを&lt;body&gt;先頭に埋め込みます。
+	 * @param parser パースした時のバージョン。
+	 * @param date パースした時の時間。
+	 */
+	protected void addVersionComment( String parser, String date ) {
+		if ( !isRuntime() )	return;
+		Tag	body = getFirstTagByType( "body" );
+		if ( body == null )	return;
+		StringBuilder	buf = new StringBuilder( " Parser(" );
+		buf = buf.append( parser );
+		buf = buf.append( "," );
+		buf = buf.append( date.toString() );
+		buf = buf.append( ") Runtime(" );
+		buf = buf.append( Version.getTitle() );
+		buf = buf.append( "," );
+		buf = buf.append( new Date().toString() );
+		buf = buf.append( ") " );
+		body.addHTMLPart( 0, new Comment( buf.toString() ) );
+	}
+
 	/**
 	 * 文書の定義設定。
 	 * @param xml true:XHTML, false:HTML。
