@@ -15,20 +15,21 @@ public class Version {
 	/**
 	 * Paraseleneのバージョン番号を表す文字列。
 	 */
-	public static final String VERSION = "1.2.0";
+	public static final String VERSION = "1.2.1";
+	private static final String	TITLE = "Paraselene  Version " + VERSION;
 
 	/**
 	 * Paraseleneのアプリタイトル文字列。
 	 */
 	public static String getTitle() {
-		return "Paraselene  Version " + VERSION;
+		return TITLE;
 	}
 
 	/**
 	 * Paraseleneの著作権表示。
 	 */
 	public static String getCopyRight() {
-		return "Copyright (c) 2009  Akira Terasaki";
+		return "Copyright 2009 Akira Terasaki";
 	}
 }
 
