@@ -767,10 +767,14 @@ public enum WebColor {
 	/**
 	 * MEDIUMSLATEBLUE
 	 */
-	MEDIUMSLATEBLUE( 0x7b, 0x68, 0xee );
-	private static final long serialVersionUID = 1247989371566L;
+	MEDIUMSLATEBLUE( 0x7b, 0x68, 0xee ),
+	/**
+	 * TRANSPARENT
+	 */
+	TRANSPARENT( 0xffffffff, 0xffffffff, 0xffffffff );
+	private static final long serialVersionUID = 1255005370014L;
 	int red, green, blue;
 	private WebColor( int r, int g, int b ) {
 		red = r;green = g;blue= b;
 	}
-}
+}
\ No newline at end of file
